from setuptools import setup

setup(name='hybridSIR',
      version='0.0',
      description='Hybrid version of the SIR model',
      packages=['hybridSIR'],
      author_email='rebeccadavidsson3@gmail.com',
      zip_safe=False)
